#!/bin/bash
# Copyright IBM Corp. 2010,2011


#
# Look for WAS, JAVA, and the JAR file.
#
# First, look for WAS.  We need it to try to find the jar file, and maybe java.
#
# Second, look for JAVA.  Look in:
#    WAS, 
#    JAVA_HOME
#    PATH
#
# Third, look for the jar file.  Look in:
#    the current directory, 
#    the script's directory, 
#    WAS_HOME/classes
#    WAS_HOME/util/ve
#
setJAVAHome()
{
	LOGMGR="logmgr.jar"
	# Set WAS home
    if [ "${REPLACE_WAS_HOME:=}" != "" ] && [ -d ${REPLACE_WAS_HOME} ];
    then
        WAS_HOME=${REPLACE_WAS_HOME}
    else
        CUR_DIR=`pwd`
        SCRIPT_DIR=`dirname ${0}`
        WAS_DIR=${SCRIPT_DIR}/../
        cd "${WAS_DIR}"
        WAS_HOME=`pwd`
        cd "${CUR_DIR}"
    fi
    
    # Try to find java. If failure, then try a local java.
    if [ -x $WAS_HOME/java/bin/java ] ; then
	   JAVA_EXE=${WAS_HOME}/java/bin/java
	elif [ -x ${WAS_HOME}/java/jre/bin/java ] ; then
	   JAVA_EXE=${WAS_HOME}/jre/bin/java
	elif [ -x ${JAVA_HOME}/bin/java ]; then
       JAVA_EXE="${JAVA_HOME}/bin/java"
	else 
   	   JAVA_EXE=`which java`
   	   if [ ! -f $JAVA_EXE ]; then
       	 echo "ERROR: Could not find java anywhere.  Try setting JAVA_HOME."
         exit 1
       fi
    fi
    
    # Try to find the trace analyzer jar.
    if [ -f ./${LOGMGR} ] ; then
       LOGJAR=./${LOGMGR}
    elif [ -f ${SCRIPT_DIR}/${LOGMGR} ]; then
       LOGJAR=${SCRIPT_DIR}/${LOGMGR}
    elif [ -f ${WAS_HOME}/classes/${LOGMGR} ]; then
       LOGJAR=${WAS_HOME}/classes/${LOGMGR}
    elif [ -f ${WAS_HOME}/util/ve/${LOGMGR} ]; then
       LOGJAR=${WAS_HOME}/util/ve/${LOGMGR}
    else 
       
       if [ ! "$CLASSPATH"="" ]; then
    	  echo "WARNING: Could not find ${LOGMGR} jar file.  I Will try using your CLASSPATH variable."
       else
         echo "ERROR: Could not find ${LOGMGR} jar file."
         exit 1
       fi
    fi
}

setJAVAHome


#
# Display the env settings, so if there's a problem, we can know
# what files were being used.
#
WAS_CLASSPATH="$LOGJAR:$CLASSPATH"
echo "WAS_HOME=$WAS_HOME"
echo "LOGJAR=$LOGJAR"
echo "WAS_CLASSPATH=$WAS_CLASSPATH"
echo "JAVA_EXE=$JAVA_EXE"
#
# Execute the analysis program.
#
${JAVA_EXE}  -Dwas.install.root="$WAS_HOME" -DSCRIPTNAME="$0" -classpath "$WAS_CLASSPATH" com.ibm.ws.logmgr.analysis.trace.RequestFlowAnalyzer "$@"
